linux-kernel.vger.kernel.org archive mirror
 help / color / mirror / Atom feed
From: Alex Dewar <alex.dewar90@gmail.com>
To: unlisted-recipients:; (no To-header on input)
Cc: Alex Dewar <alex.dewar90@gmail.com>,
	Sebastian Reichel <sre@kernel.org>,
	linux-pm@vger.kernel.org, linux-kernel@vger.kernel.org
Subject: [PATCH] power: supply: charger-manager: Tidy function
Date: Wed,  2 Sep 2020 17:58:16 +0100	[thread overview]
Message-ID: <20200902165816.401213-1-alex.dewar90@gmail.com> (raw)

check_charging_duration() contains some copy-pasted code, which makes it
less readable. Refactor the function to be a bit tidier.

I've also fixed a couple of typos.

Signed-off-by: Alex Dewar <alex.dewar90@gmail.com>
---
 drivers/power/supply/charger-manager.c | 39 +++++++++-----------------
 1 file changed, 14 insertions(+), 25 deletions(-)

diff --git a/drivers/power/supply/charger-manager.c b/drivers/power/supply/charger-manager.c
index 07992821e252..67c7b1fb6601 100644
--- a/drivers/power/supply/charger-manager.c
+++ b/drivers/power/supply/charger-manager.c
@@ -443,42 +443,31 @@ static int try_charger_enable(struct charger_manager *cm, bool enable)
  * check_charging_duration - Monitor charging/discharging duration
  * @cm: the Charger Manager representing the battery.
  *
  * If whole charging duration exceed 'charging_max_duration_ms',
  * cm stop charging to prevent overcharge/overheat. If discharging
  * duration exceed 'discharging _max_duration_ms', charger cable is
  * attached, after full-batt, cm start charging to maintain fully
  * charged state for battery.
  */
 static int check_charging_duration(struct charger_manager *cm)
 {
 	struct charger_desc *desc = cm->desc;
-	u64 curr = ktime_to_ms(ktime_get());
 	u64 duration;
-	int ret = false;
 
-	if (!desc->charging_max_duration_ms &&
-			!desc->discharging_max_duration_ms)
-		return ret;
-
-	if (cm->charger_enabled) {
-		duration = curr - cm->charging_start_time;
-
-		if (duration > desc->charging_max_duration_ms) {
-			dev_info(cm->dev, "Charging duration exceed %ums\n",
-				 desc->charging_max_duration_ms);
-			ret = true;
-		}
-	} else if (cm->battery_status == POWER_SUPPLY_STATUS_NOT_CHARGING) {
-		duration = curr - cm->charging_end_time;
+	if ((desc->charging_max_duration_ms == 0 &&
+			desc->discharging_max_duration_ms == 0))
+		return false;
+	if (!cm->charger_enabled &&
+			cm->battery_status != POWER_SUPPLY_STATUS_NOT_CHARGING)
+		return false;
 
-		if (duration > desc->charging_max_duration_ms) {
-			dev_info(cm->dev, "Discharging duration exceed %ums\n",
-				 desc->discharging_max_duration_ms);
-			ret = true;
-		}
+	duration = ktime_to_ms(ktime_get()) - cm->charging_start_time;
+	if (duration > desc->charging_max_duration_ms) {
+		dev_info(cm->dev, "Charging duration exceeds %ums\n",
+				desc->charging_max_duration_ms);
+		return true;
 	}
-
-	return ret;
+	return false;
 }
 
 static int cm_get_battery_temperature_by_psy(struct charger_manager *cm,
@@ -443,42 +443,31 @@ static int try_charger_enable(struct charger_manager *cm, bool enable)
  * @cm: the Charger Manager representing the battery.
  *
- * If whole charging duration exceed 'charging_max_duration_ms',
+ * If whole charging duration exceeds 'charging_max_duration_ms',
  * cm stop charging to prevent overcharge/overheat. If discharging
@@ -443,42 +443,31 @@ static int try_charger_enable(struct charger_manager *cm, bool enable)
  * cm stop charging to prevent overcharge/overheat. If discharging
- * duration exceed 'discharging _max_duration_ms', charger cable is
+ * duration exceeds 'discharging _max_duration_ms', charger cable is
  * attached, after full-batt, cm start charging to maintain fully
  * charged state for battery.
-- 
2.28.0


             reply	other threads:[~2020-09-02 16:58 UTC|newest]

Thread overview: 3+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2020-09-02 16:58 Alex Dewar [this message]
2020-09-19 19:32 ` [PATCH] power: supply: charger-manager: Tidy function Alex Dewar
2020-10-08 22:35 ` Sebastian Reichel

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20200902165816.401213-1-alex.dewar90@gmail.com \
    --to=alex.dewar90@gmail.com \
    --cc=linux-kernel@vger.kernel.org \
    --cc=linux-pm@vger.kernel.org \
    --cc=sre@kernel.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).